#!/bin/sh

# This script should be called from connector_manager.sh, and accepts the following parameters:
#  start_WebSphereMQWorkflow.sh <CONNECTORNAME> <SERVERNAME> <OPTIONAL ADDITIONAL PARAMETERS>
#
#The file CWSharedEnv.sh defines the following in it's classpath, so there is no need to override any of these:
#Please go look at this file, on the solaris build, it is in the $CROSSWORLDS/setup directory.
#All of these are bundeled together into the CLASSPATH variable which is then exported for your use
#It defines things such as:
#CORECW
#RSA 
#CWUTILS 
#XML_PARSER 
#DATAHANDLERS 
#MQ 
#ORB1 
#ORB2 
#JVM_FLAGS 
#JRT 
#JAVA_SECURITY 
#WEBLOGIC 
#

################################################
# General connector variable initialization section
# No changes should be necessary
# set CONNECTOR_TYPE  -- This is needed to differentate Java from C++ conncetors 
# set CONDIR  the directory where the specific connector resides, then change to this directory
# set CONNAME the name to be the application connector that is starting
# set SERVER  the server name to be the interchange that is being targeted
# set CONJAR to the fullpath of the connector .jar file.

# Begin as per the new run-time code split
#################################################
# set the name to be the application connector that is starting
CONNAME=$1
# set the server name to be the interchange that is being targeted
SERVER=$2
# call CWConnEnv to setup connector environment
. ${CROSSWORLDS}/bin/CWConnEnv.sh
echo $CWCLASSES
# set absolute path for connector directory and update library path
CONDIR=${CROSSWORLDS}/connectors/${CONNAME}
if [ "${OS}" = "SUNOS" ]
then
LD_LIBRARY_PATH=${CONDIR}:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH
elif [ "${OS}" = "HP-UX" ]
then
SHLIB_PATH=${CONDIR}:${SHLIB_PATH}
export SHLIB_PATH
elif [ "${OS}" = "LINUX" ]
then
LD_LIBRARY_PATH=${CONDIR}:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH
else
LIBPATH=${CONDIR}:${LIBPATH}
export LIBPATH
fi
################################################
# Connector specific variable initialization section

# Set your Connector agent here 
CONNECTOR_TYPE="-l"                                                                     
CONNECTOR_AGENT=com.crossworlds.connectors.mqworkflow.MQWorkflowConnectorAgent 
CONJAR=${CONDIR}/CW${CONNAME}.jar
# Set any Connector specific start options here (Like -t or -fno etc.)
CON_START_OPTIONS=" "

#Set the directory containing your MQSeries Workflow client libraries
MQWF_JAVA_LIB_PATH=/opt/fmc/bin/java3320
CON_SPEC_JAR_MQWF=${MQWF_JAVA_LIB_PATH}/fmcojagt.jar:${MQWF_JAVA_LIB_PATH}/fmcojapi.jar

################################################
# Begin with new run-time code split
if [ -f $CROSSWORLDS/wbiart/wbiart.jar ]
then
# Going to the directory where the connector class files reside
cd /
cd "${CONDIR}"
#set JCLASSES
JCLASSES=.:${CONJAR}:${CON_SPEC_JAR_MQWF}:${CWCLASSES}:${JCLASSES}
export JCLASSES

# Call the base start_adapter.sh to start the connector
exec start_adapter.sh ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS} $3 $4

else
#all old functionality goes here

# Step 1: Set the directory containing your MQSeries Java client libraries 
MQ_JAVA_LIB=/opt/mqm/java/lib
CON_SPEC_JAR_MQ=${MQ_JAVA_LIB}/connector.jar:${MQ_JAVA_LIB}/jms.jar:${MQ_JAVA_LIB}/jndi.jar:${MQ_JAVA_LIB}/com.ibm.mq.jar:${MQ_JAVA_LIB}/com.ibm.mqjms.jar

# Step 2: Set the directory containing your MQSeries Workflow client libraries
#this is set as global part of the connnector specific script

# Set your Connector agent here 
#this is set as global part of the connnector specific script

#CON_SPEC_JAR_XML=${CONDIR}/dependencies/Sun/jaxp.jar:${CONDIR}/dependencies/Sun/parser.jar
CON_SPEC_JAR_XML=${CROSSWORLDS}/lib/xerces.jar

MQWF_BOOTSTRAP=""
# Step 3: If using the OSA agent locator policy (Visibroker), uncomment
# the following lines and adjust visibroker library paths as necessary
#MQWF_VBROKER_LIB_PATH=/opt/vbroker/lib
#MQWF_BOOTSTRAP=-Xbootclasspath/p:${MQWF_VBROKER_LIB_PATH}/vbjapp.jar:${MQWF_VBROKER_LIB_PATH}/vbjorb.jar:${MQWF_VBROKER_PATH}/vbjtools.jar:${MQWF_VBROKER_LIB_PATH}/vbjcosm.jar


# Set Conn specific classpath here 
#Any specific variables defined above need to be added to the CON_SPECIFIC_CLASSPATH below.
CON_SPECIFIC_CLASSPATH=${CON_SPEC_JAR_MQ}:${CON_SPEC_JAR_MQWF}

# Set any Connector specific start options here (Like -t or -fno etc.)
#this is set as global part of the connnector specific script                                                            
 
# We are using the JVM_FLAGS that are set in the CWSharedEnv.sh file, if you need to use different flags,
#  Change $JVM_FLAGS to be what you need to use.
# No changes should be necessary below this line.

JVM_FLAGS=-Djava.library.path="/usr/lpp/fmc/lib":${JVM_FLAGS}
CWCLASSES=${CWCLASSES}
CLASSPATH=.:${CON_SPEC_JAR_XML}:${CONJAR}:${CON_SPECIFIC_CLASSPATH}:${CWCLASSES}
echo $CLASSPATH
${CROSSWORLDS}/bin/check_path.sh "$CLASSPATH"

if [ "${OS}" = "SUNOS" ]
then
exec ${CWJAVA} ${JVM_FLAGS} ${MQWF_BOOTSTRAP} -Djava.library.path=${LD_LIBRARY_PATH} -Djava.ext.dirs=${JRE_EXT_DIRS} -classpath ${CLASSPATH}  AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS}  $3 $4 $5 $6 $7 $8 $9
elif [ "${OS}" = "HP-UX" ]
then
exec ${CWJAVA} ${JVM_FLAGS} ${MQWF_BOOTSTRAP} -Djava.library.path=${SHLIB_PATH} -Djava.ext.dirs=${JRE_EXT_DIRS} -classpath ${CLASSPATH}  AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS}  $3 $4 $5 $6 $7 $8 $9
else
exec ${CWJAVA} ${JVM_FLAGS} ${MQWF_BOOTSTRAP} -Djava.library.path=${LIBPATH} -Djava.ext.dirs=${JRE_EXT_DIRS} -classpath ${CLASSPATH}  AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS}  $3 $4 $5 $6 $7 $8 $9
fi
#end nested if
fi
